@@ -17,7 +17,8 @@ sub EXT_controller : Extend('Ext.app.ViewController') : Type('controller') {
         },
 
         # MATERIAL THEME
-        theme => {
+        currentTheme => undef,
+        defautTheme  => {
             accent   => 'grey',
             base     => 'blue-grey',
             darkMode => \0
@@ -60,9 +61,11 @@ sub EXT_controller : Extend('Ext.app.ViewController') : Type('controller') {
             }
 
             // set material theme
-            me.setTheme(me.theme, true);
+            me.setTheme();
 
             this.getViewModel().bind('{session.theme.darkMode}', function (newVal, oldVal, eOpt) {
+                if (newVal == null) return;
+
                 this.setTheme({ darkMode: newVal });
             }, this);
 
@@ -152,7 +155,7 @@ JS
             session.locale = locale;
             session.localeName = session.locales[locale];
 
-            session.theme = this.theme;
+            session.theme = this.currentTheme;
 
             // update viewModel
             var viewModel = this.getViewModel();
@@ -162,24 +165,25 @@ JS
 JS
 
         # MATERIAL THEME
-        setTheme => func [ 'newTheme', 'isDefaultTheme' ], <<"JS",
+        setTheme => func ['theme'], <<"JS",
             if (Ext.theme.Material) {
                 Ext.manifest.material = Ext.manifest.material || {};
                 Ext.manifest.material.toolbar = Ext.manifest.material.toolbar || {};
                 Ext.manifest.material.toolbar.dynamic = true;
 
-                var userTheme = localStorage.theme ? JSON.parse(localStorage.theme) : {};
+                var userTheme = this.currentTheme;
+                if (!userTheme) userTheme = localStorage.theme ? JSON.parse(localStorage.theme) : {};
 
-                if (isDefaultTheme) {
-                    this.theme = Ext.apply(newTheme, userTheme);
+                if (!theme) {
+                    this.currentTheme = Ext.apply({}, userTheme, this.defaultTheme);
                 }
                 else {
-                    this.theme = Ext.apply(this.theme, newTheme);
+                    this.currentTheme = Ext.apply({}, theme, userTheme);
 
-                    localStorage.theme = JSON.stringify(this.theme);
+                    localStorage.theme = JSON.stringify(this.currentTheme);
                 }
 
-                Ext.theme.Material.setColors(this.theme);
+                Ext.theme.Material.setColors(this.currentTheme);
             }
 JS
 
